@@ -2,7 +2,7 @@ package DateTimeX::Mashup::Shiras;
 BEGIN {
   $DateTimeX::Mashup::Shiras::AUTHORITY = 'cpan:JANDREW';
 }
-use version 0.77; our $VERSION = qv("v0.32.4");
+use version 0.77; our $VERSION = qv("v0.32.6");
 
 if( $ENV{ Smart_Comments } ){
 	use Smart::Comments -ENV;
@@ -416,9 +416,9 @@ L<Smart::Comments>
 
 =over
 
-=item Jed Lund
+Jed Lund
 
-=item jandrew@cpan.org
+jandrew@cpan.org
 
 =back
 
@@ -431,7 +431,7 @@ patches, bug reports, help with troubleshooting, etc. A huge
 
 =over
 
-=item Toby Inkster
+L<Toby Inkster|https://github.com/tobyink>
 
 =back
 
